---
title: diamonds
id: diamonds-data
label: diamonds data
---

```{r}
library(ggplot2)

diamonds |>
    dplyr::slice_sample(n = 1000) |>
    ggplot() +
    geom_point(aes(x = carat, y = price, color = cut))
```
